@@ -1,6 +1,6 @@
 # ABSTRACT: create new Dancer2 application
 package Dancer2::CLI::Command::gen;
-$Dancer2::CLI::Command::gen::VERSION = '0.205002';
+$Dancer2::CLI::Command::gen::VERSION = '0.206000';
 use strict;
 use warnings;
 
@@ -10,7 +10,7 @@ use HTTP::Tiny;
 use File::Find;
 use File::Path 'mkpath';
 use File::Spec::Functions;
-use File::ShareDir 'dist_dir';
+use File::Share 'dist_dir';
 use File::Basename qw/dirname basename/;
 use Dancer2::Template::Simple;
 use Module::Runtime 'require_module';
@@ -298,7 +298,7 @@ Dancer2::CLI::Command::gen - create new Dancer2 application
 
 =head1 VERSION
 
-version 0.205002
+version 0.206000
 
 =head1 AUTHOR
 
@@ -306,7 +306,7 @@ Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Alexis Sukrieh.
+This software is copyright (c) 2018 by Alexis Sukrieh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
